Developing addons
=================

:ref:`addons` are way to customize localization workflow in Weblate.

.. currentmodule:: weblate.addons.base

.. autoclass:: BaseAddon
    :members:

Here is an example addon:

.. literalinclude:: ../../weblate/addons/example.py
    :language: python
